@@ -4,6 +4,18 @@ import copy
 from datetime import datetime
 
 
+def get_response(code, body):
+    if type(body) in [dict, list]:
+        return {
+            "statusCode": code,
+            "body": json.dumps(body)
+        }
+    else:
+        return {
+            "statusCode": code,
+            "body": body
+        }
+
 def get_config():
     with open(os.path.dirname(__file__) + "/../config.json", "r") as read_file:
         config = json.load(read_file)
